# Easy My Coop Website

> This module adds the cooperator subscription form allowing to subscribe for
>   shares online.

Table of contents

- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us smashing it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- Coop IT Easy SCRLfs

## Contributors

- Coop IT Easy SCRLfs

## Maintainers

This module is part of the coopiteasy/vertical-cooperative project on GitHub.

You are welcome to contribute.